CrossChainRouteFilter

Enum CrossChainRouteFilter 

pub enum CrossChainRouteFilter {
    Send {
        address_details: CrossChainAddressDetails,
    },
    Receive {
        contract_address: Option<String>,
    },
    PaymentLink {
        address_details: CrossChainAddressDetails,
    },
}
Filter for [CrossChainService::get_routes] and the public get_cross_chain_routes() API.

Variants



Send

Routes for sending from the Spark wallet to another chain. Filtered by the parsed recipient address details.

Fields



Receive

Routes for receiving to Spark from another chain. Optionally filtered by the source token contract address.

Fields

contract_address: Option<String>

Routes for a payment link that sends a stablecoin funded by an external rail (Cash App over Lightning) rather than the Spark wallet. Filtered by the parsed recipient address details.

Fields