pub enum PaymentDetails {
Spark {
invoice_details: Option<SparkInvoicePaymentDetails>,
htlc_details: Option<SparkHtlcDetails>,
conversion_info: Option<ConversionInfo>,
},
Token {
metadata: TokenMetadata,
tx_hash: String,
tx_type: TokenTransactionType,
invoice_details: Option<SparkInvoicePaymentDetails>,
conversion_info: Option<ConversionInfo>,
},
Lightning {
description: Option<String>,
invoice: String,
destination_pubkey: String,
htlc_details: SparkHtlcDetails,
lnurl_pay_info: Option<LnurlPayInfo>,
lnurl_withdraw_info: Option<LnurlWithdrawInfo>,
lnurl_receive_metadata: Option<LnurlReceiveMetadata>,
conversion_info: Option<ConversionInfo>,
},
Withdraw {
tx_id: String,
},
Deposit {
tx_id: String,
vout: u32,
},
}Variants
Spark
Fields
invoice_details: Option<SparkInvoicePaymentDetails>The invoice details if the payment fulfilled a spark invoice
htlc_details: Option<SparkHtlcDetails>The HTLC transfer details if the payment fulfilled an HTLC transfer
conversion_info: Option<ConversionInfo>The information for a conversion
Token
Fields
metadata: TokenMetadatatx_type: TokenTransactionTypeinvoice_details: Option<SparkInvoicePaymentDetails>The invoice details if the payment fulfilled a spark invoice
conversion_info: Option<ConversionInfo>The information for a conversion
Lightning
Fields
invoice: StringRepresents the Bolt11/Bolt12 invoice associated with a payment In the case of a Send payment, this is the invoice paid by the user In the case of a Receive payment, this is the invoice paid to the user
htlc_details: SparkHtlcDetailsThe HTLC transfer details
lnurl_pay_info: Option<LnurlPayInfo>Lnurl payment information if this was an lnurl payment.
lnurl_withdraw_info: Option<LnurlWithdrawInfo>Lnurl withdrawal information if this was an lnurl payment.
lnurl_receive_metadata: Option<LnurlReceiveMetadata>Lnurl receive information if this was a received lnurl payment.
conversion_info: Option<ConversionInfo>The information for a conversion — populated when this Lightning payment is the source leg of a cross-chain conversion (e.g. a Boltz reverse swap paying a hold invoice).
Withdraw
Deposit