pub enum SparkMasterIdentityPublicKey {
Set {
public_key: String,
},
Unset,
}Expand description
Specifies how to update the wallet’s Spark master identity public key.
Variants
Set
Designate the holder of this public key as the wallet’s master identity, replacing any previously designated key. Must be hex encoded in the 33-byte compressed form.
Unset
Remove the designated master identity, leaving the owner as the only party able to read the wallet under private mode.