get_spark_status

Function get_spark_status 

pub async fn get_spark_status() -> Result<SparkStatus, SdkError>
Fetches the current status of Spark network services relevant to the SDK.

This function queries the Spark status API and returns the worst status across the Spark Operators and SSP services.