pub struct BuyBitcoinRequest {
pub locked_amount_sat: Option<u64>,
pub redirect_url: Option<String>,
}Expand description
Request to buy Bitcoin using an external provider (MoonPay)
Fields
locked_amount_sat: Option<u64>Optional: Lock the purchase to a specific amount in satoshis. When provided, the user cannot change the amount in the purchase flow.
redirect_url: Option<String>Optional: Custom redirect URL after purchase completion