pub struct ConnectWithSignerRequest {
pub config: Config,
pub breez_signer: Arc<dyn ExternalBreezSigner>,
pub spark_signer: Arc<dyn ExternalSparkSigner>,
pub storage_dir: String,
}Expand description
Request object for connecting to the Spark network using an external signer.
This allows using a custom signer implementation instead of providing a seed directly.
Fields
config: Configbreez_signer: Arc<dyn ExternalBreezSigner>External signer for non-Spark SDK signing (LNURL-auth, sync, message signing, ECIES).
spark_signer: Arc<dyn ExternalSparkSigner>External high-level Spark signer for the Spark wallet flows.
storage_dir: StringAuto Trait Implementations
impl Freeze for ConnectWithSignerRequest
impl !RefUnwindSafe for ConnectWithSignerRequest
impl Send for ConnectWithSignerRequest
impl Sync for ConnectWithSignerRequest
impl Unpin for ConnectWithSignerRequest
impl UnsafeUnpin for ConnectWithSignerRequest
impl !UnwindSafe for ConnectWithSignerRequest