pub struct ConversionStep {
pub payment_id: String,
pub amount: u128,
pub fee: u128,
pub method: PaymentMethod,
pub token_metadata: Option<TokenMetadata>,
}Expand description
A single step in a conversion
Fields
payment_id: StringThe underlying payment id of the conversion step
amount: u128Payment amount in satoshis or token base units
fee: u128Fee paid in satoshis or token base units This represents the payment fee + the conversion fee
method: PaymentMethodMethod of payment
token_metadata: Option<TokenMetadata>Token metadata if a token is used for payment