pub struct LnurlPayRequest {
pub prepare_response: PrepareLnurlPayResponse,
pub idempotency_key: Option<String>,
}Fields
prepare_response: PrepareLnurlPayResponseidempotency_key: Option<String>If set, providing the same idempotency key for multiple requests will ensure that only one payment is made. If an idempotency key is re-used, the same payment will be returned. The idempotency key must be a valid UUID.