LnurlWithdrawRequest

Struct LnurlWithdrawRequest 

pub struct LnurlWithdrawRequest {
    pub amount_sats: u64,
    pub withdraw_request: LnurlWithdrawRequestDetails,
    pub completion_timeout_secs: Option<u32>,
}

Fields

amount_sats: u64

The amount to withdraw in satoshis Must be within the min and max withdrawable limits

withdraw_request: LnurlWithdrawRequestDetailscompletion_timeout_secs: Option<u32>

If set, the function will return the payment if it is still pending after this number of seconds. If unset, the function will return immediately after initiating the LNURL withdraw.