OptimizationConfig

Struct OptimizationConfig 

pub struct OptimizationConfig {
    pub auto_enabled: bool,
    pub multiplicity: u8,
}

Fields

auto_enabled: bool

Whether automatic leaf optimization is enabled.

If set to true, the SDK will automatically optimize the leaf set when it changes. Otherwise, the manual optimization API must be used to optimize the leaf set.

Default value is true.

multiplicity: u8

The desired multiplicity for the leaf set.

Setting this to 0 will optimize for maximizing unilateral exit. Higher values will optimize for minimizing transfer swaps, with higher values being more aggressive and allowing better TPS rates.

For end-user wallets, values of 1-5 are recommended. Values above 5 are intended for high-throughput server environments and are not recommended for end-user wallets due to significantly higher unilateral exit costs.

Default value is 1.