pub struct Payment {
pub id: String,
pub payment_type: PaymentType,
pub status: PaymentStatus,
pub amount: u128,
pub fees: u128,
pub timestamp: u64,
pub method: PaymentMethod,
pub details: Option<PaymentDetails>,
pub conversion_details: Option<ConversionDetails>,
}Expand description
Represents a payment (sent or received)
Fields
id: StringUnique identifier for the payment
payment_type: PaymentTypeType of payment (send or receive)
status: PaymentStatusStatus of the payment
amount: u128Amount in satoshis or token base units
fees: u128Fee paid in satoshis or token base units
timestamp: u64Timestamp of when the payment was created
method: PaymentMethodMethod of payment. Sometimes the payment details is empty so this field is used to determine the payment method.
details: Option<PaymentDetails>Details of the payment
conversion_details: Option<ConversionDetails>If set, this payment involved a conversion before the payment
Implementations
Sourceimpl Payment
impl Payment
Sourcepub fn from_lightning(
payment: LightningSendPayment,
amount_sat: u128,
transfer_id: String,
htlc_details: SparkHtlcDetails,
) -> Result<Self, SdkError>
pub fn from_lightning( payment: LightningSendPayment, amount_sat: u128, transfer_id: String, htlc_details: SparkHtlcDetails, ) -> Result<Self, SdkError>
Creates a Payment from a [LightningSendPayment] and its associated HTLC details.
The htlc_details may be stale (e.g. captured at payment creation time), so this
method reconciles them with the current state of the payment:
- The preimage is taken from
htlc_detailsif present, otherwise from the payment. - If a preimage is available from either source, the HTLC status is set to
SparkHtlcStatus::PreimageShared.