pub struct PerBranchFunding {
pub leaf_id: String,
pub funding_sat: u64,
}Expand description
How much to fund one branch of the exit to avoid a fan-out.
Fields
leaf_id: StringThe leaf whose branch this funds.
funding_sat: u64Fund a UTXO of at least this many satoshis for this branch.