pub struct PrepareLnurlPayRequest {
pub amount: u128,
pub pay_request: LnurlPayRequestDetails,
pub comment: Option<String>,
pub validate_success_action_url: Option<bool>,
pub token_identifier: Option<String>,
pub conversion_options: Option<ConversionOptions>,
pub fee_policy: Option<FeePolicy>,
}Fields
amount: u128The amount to send. Denominated in satoshis, or in token base units
when token_identifier is set.
pay_request: LnurlPayRequestDetailscomment: Option<String>validate_success_action_url: Option<bool>token_identifier: Option<String>The token identifier when sending a token amount with conversion.
conversion_options: Option<ConversionOptions>If provided, the payment will include a token conversion step before sending the payment
fee_policy: Option<FeePolicy>How fees are handled. See FeePolicy. Defaults to FeesExcluded.