pub struct PrepareLnurlPayResponse {
pub amount_sats: u64,
pub comment: Option<String>,
pub pay_request: LnurlPayRequestDetails,
pub fee_sats: u64,
pub invoice_details: Bolt11InvoiceDetails,
pub success_action: Option<SuccessAction>,
pub conversion_estimate: Option<ConversionEstimate>,
pub fee_policy: FeePolicy,
}Fields
amount_sats: u64The amount for the payment, always denominated in sats, even when a
token_identifier and conversion are present.
When a conversion is present, the token input amount is available in
conversion_estimate.amount_in.
comment: Option<String>pay_request: LnurlPayRequestDetailsfee_sats: u64The fee in satoshis. For FeesIncluded operations, this represents the total fee
(including potential overpayment).
invoice_details: Bolt11InvoiceDetailssuccess_action: Option<SuccessAction>conversion_estimate: Option<ConversionEstimate>When set, the payment will include a token conversion step before sending the payment
fee_policy: FeePolicyThe fee policy actually applied. May differ from the request — e.g.,
LNURL sends with token_identifier set + conversion are always
FeesIncluded (explicit FeesExcluded is rejected).