pub struct PrepareSendBatchResponse {
pub recipients: Vec<ResolvedBatchRecipient>,
pub totals: Vec<BatchTotal>,
}Fields
recipients: Vec<ResolvedBatchRecipient>The payees in the order they were requested, which is the order their payments come back in.
totals: Vec<BatchTotal>What the batch debits, one entry per distinct asset.