pub struct PrepareSendPaymentResponse {
pub payment_method: SendPaymentMethod,
pub amount: u128,
pub token_identifier: Option<String>,
pub conversion_estimate: Option<ConversionEstimate>,
pub fee_policy: FeePolicy,
}Fields
payment_method: SendPaymentMethodamount: u128The amount to be sent, denominated in satoshis for Bitcoin payments
(including token-to-Bitcoin conversions), or token base units for token payments.
When a conversion is present, the input amount is in
conversion_estimate.amount_in.
token_identifier: Option<String>Optional token identifier for token payments. Absence indicates that the payment is a Bitcoin payment.
conversion_estimate: Option<ConversionEstimate>When set, the payment will include a conversion step before sending the payment
fee_policy: FeePolicyThe fee policy actually applied. May differ from the request — e.g.,
cross-chain AMM-conversion sends are always FeesIncluded.