pub struct ResolvedBatchRecipient {
pub destination: BatchDestination,
pub amount: u128,
pub token_identifier: Option<String>,
}Expand description
A recipient after prepare has resolved the asset and amount it is owed.
Fields
destination: BatchDestinationamount: u128Amount in the base units of the asset this recipient is paid in.
token_identifier: Option<String>The token this recipient is paid in. Unset means sats, which a batch cannot send yet.