pub struct SparkStatus {
pub status: ServiceStatus,
pub last_updated: u64,
}Expand description
The status of the Spark network services relevant to the SDK.
Fields
status: ServiceStatusThe worst status across all relevant services.
last_updated: u64The last time the status was updated, as a unix timestamp in seconds.