pub struct Config {Show 14 fields
pub api_key: Option<String>,
pub network: Network,
pub sync_interval_secs: u32,
pub max_deposit_claim_fee: Option<MaxFee>,
pub lnurl_domain: Option<String>,
pub prefer_spark_over_lightning: bool,
pub external_input_parsers: Option<Vec<ExternalInputParser>>,
pub use_default_external_input_parsers: bool,
pub real_time_sync_server_url: Option<String>,
pub private_enabled_default: bool,
pub optimization_config: OptimizationConfig,
pub stable_balance_config: Option<StableBalanceConfig>,
pub max_concurrent_claims: u32,
pub support_lnurl_verify: bool,
}Fields
api_key: Option<String>network: Networksync_interval_secs: u32max_deposit_claim_fee: Option<MaxFee>lnurl_domain: Option<String>The domain used for receiving through lnurl-pay and lightning address.
prefer_spark_over_lightning: boolWhen this is set to true we will prefer to use spark payments over
lightning when sending and receiving. This has the benefit of lower fees
but is at the cost of privacy.
external_input_parsers: Option<Vec<ExternalInputParser>>A set of external input parsers that are used by BreezSdk::parse when the input
is not recognized. See ExternalInputParser for more details on how to configure
external parsing.
use_default_external_input_parsers: boolThe SDK includes some default external input parsers
(DEFAULT_EXTERNAL_INPUT_PARSERS).
Set this to false in order to prevent their use.
real_time_sync_server_url: Option<String>Url to use for the real-time sync server. Defaults to the Breez real-time sync server.
private_enabled_default: boolWhether the Spark private mode is enabled by default.
If set to true, the Spark private mode will be enabled on the first initialization of the SDK. If set to false, no changes will be made to the Spark private mode.
optimization_config: OptimizationConfigConfiguration for leaf optimization.
Leaf optimization controls the denominations of leaves that are held in the wallet. Fewer, bigger leaves allow for more funds to be exited unilaterally. More leaves allow payments to be made without needing a swap, reducing payment latency.
stable_balance_config: Option<StableBalanceConfig>Configuration for automatic conversion of Bitcoin to stable tokens.
When set, received sats will be automatically converted to the specified token once the balance exceeds the threshold.
max_concurrent_claims: u32Maximum number of concurrent transfer claims.
Default is 4. Increase for server environments with high incoming payment volume.
support_lnurl_verify: boolWhen true, enables LNURL verify support (LUD-21) and zap receipts (NIP-57). When false (default), these features are disabled for privacy.
Implementations