pub struct ConnectWithSignerRequest {
pub config: Config,
pub signer: Arc<dyn ExternalSigner>,
pub storage_dir: String,
}Expand description
Request object for connecting to the Spark network using an external signer.
This allows using a custom signer implementation instead of providing a seed directly.
Fields
config: Configsigner: Arc<dyn ExternalSigner>storage_dir: StringAuto Trait Implementations
impl Freeze for ConnectWithSignerRequest
impl !RefUnwindSafe for ConnectWithSignerRequest
impl Send for ConnectWithSignerRequest
impl Sync for ConnectWithSignerRequest
impl Unpin for ConnectWithSignerRequest
impl UnsafeUnpin for ConnectWithSignerRequest
impl !UnwindSafe for ConnectWithSignerRequest