pub struct PrepareSendPaymentRequest {
pub payment_request: String,
pub amount: Option<u128>,
pub token_identifier: Option<String>,
pub conversion_options: Option<ConversionOptions>,
pub fee_policy: Option<FeePolicy>,
}Fields
payment_request: Stringamount: Option<u128>The amount to send. Optional for payment requests with embedded amounts (e.g., Spark/Bolt11 invoices with amounts). Required for Spark addresses, Bitcoin addresses, and amountless invoices. Denominated in satoshis for Bitcoin payments, or token base units for token payments.
token_identifier: Option<String>Optional token identifier for token payments. Absence indicates that the payment is a Bitcoin payment.
conversion_options: Option<ConversionOptions>If provided, the payment will include a conversion step before sending the payment
fee_policy: Option<FeePolicy>How fees should be handled. Defaults to FeesExcluded (fees added on top).