pub struct PrepareSendPaymentResponse {
pub payment_method: SendPaymentMethod,
pub amount: u128,
pub token_identifier: Option<String>,
pub conversion_estimate: Option<ConversionEstimate>,
pub fee_policy: FeePolicy,
}Fields
payment_method: SendPaymentMethodamount: u128The amount for the payment. Denominated in satoshis for Bitcoin payments, or token base units for token payments.
token_identifier: Option<String>Optional token identifier for token payments. Absence indicates that the payment is a Bitcoin payment.
conversion_estimate: Option<ConversionEstimate>When set, the payment will include a conversion step before sending the payment
fee_policy: FeePolicyHow fees are handled for this payment.